@@ -21,10 +21,8 @@
  * Programming and concept: Mark Veinot
  * Creates custom e-mail signatures
  * --------------------------------
- * For a version of TaRT for the Microsoft Windows 95/NT
- * environments, see my web page: http://mvgrafx.dyn.ca/~vmark
  *
- * Feel free to e-mail me at: vmark@nbnet.nb.ca
+ * Feel free to e-mail me at: mveinot@gmail.com
  * with any questions, comments, suggestions, or (yes, even)
  * complaints.
  */
@@ -36,8 +34,9 @@
 #endif
 
 #ifdef __linux__
-#include <linux/kernel.h>
-#include <linux/sys.h>
+// todo: We get a warning about using kernel headers in userspace here.
+// ideally there is a way to get this information without using a kernel
+// header and also without just reading /proc/uptime
 #include <sys/sysinfo.h>
 #endif
 
@@ -256,7 +255,11 @@ int main (int argc, char *argv[])
 			else
 				_exit(0);
 		}
-		chdir ("/");	// change directory to / to avoid umount problems
+		if (chdir ("/") == -1)
+		{
+			printf("failed to change dir during fork\n");
+			exit(1);
+		}	// change directory to / to avoid umount problems
 		umask(0);	// change umask to 0 for full control
 
 		/* install our signal handlers */
@@ -286,7 +289,7 @@ int main (int argc, char *argv[])
 
 void Help (void)
 {
-        printf (BLUE "\nLinuxTaRT" GREEN " version %.2f " WHITE " Compiled: (%s)\n" NORMAL, VER, __DATE__);
+	printf (BLUE "\nLinuxTaRT" GREEN " version %.2f " WHITE " Compiled: (%s)\n" NORMAL, VER, __DATE__);
 	HLine (74);
 	printf ("Command line email signature creator\n");
 	printf ("\n");
@@ -307,8 +310,6 @@ void Help (void)
 	printf (" [+/-]q\t\tenable/disable quiet mode\t\t[default = off]\n");
 	printf (" [+/-]sd\tenable/disable special dates\t\t[default = on]\n");
 	printf (" [+/-]v\t\tenable/disable TaRT version info\t[default = on]\n");
-	HLine (74);
-	printf (BLUE "\nWritten by Mark Veinot" NORMAL "  --  " BLUE "vmark@nbnet.nb.ca\n\n" NORMAL);
 	exit (0);
 }
 
@@ -385,14 +386,14 @@ int MakeTag (char custom1[], char custom2[], char filename[], char tagfile[], ch
 	fprintf (outfile, "%s\n", custom1);	/*  to the file, line by line */
 	fprintf (outfile, "%s\n", HLINE);
 	if (optarray[date])
-		fprintf (outfile, dateToday);
+		fprintf (outfile, "%s", dateToday);
 	if (optarray[date])
 		fprintf (outfile, "\n");
 	fprintf (outfile, "%s", tagline);
 	if (optarray[version])
 		fprintf (outfile, "\n");
 	if (optarray[version])
-		fprintf (outfile, VersionInfo);
+		fprintf (outfile, "%s", VersionInfo);
 	fprintf (outfile, "%s\n", HLINE);
 	fprintf (outfile, "%s\n", custom2);
 	fprintf (outfile, "%s", HLINE);
@@ -515,21 +516,21 @@ int MakeTagCustom (char custom1[], char custom2[], char filename[], char tagfile
 #endif
 				
 				if (strncmp (fmt, "c1", 2) == 0)
-					fprintf (outfile, custom1);
+					fprintf (outfile, "%s", custom1);
 				if (strncmp (fmt, "c2", 2) == 0)
-					fprintf (outfile, custom2);
+					fprintf (outfile, "%s", custom2);
 				if (strncmp (fmt, "dt", 2) == 0)
-					fprintf (outfile, dateToday);
+					fprintf (outfile, "%s", dateToday);
 				if (strncmp (fmt, "12", 2) == 0)
-					fprintf (outfile, Hour12);
+					fprintf (outfile, "%s", Hour12);
 				if (strncmp (fmt, "24", 2) == 0)
-					fprintf (outfile, Hour24);
+					fprintf (outfile, "%s", Hour24);
 				if (strncmp (fmt, "mn", 2) == 0)
-					fprintf (outfile, Minute);
+					fprintf (outfile, "%s", Minute);
 				if (strncmp (fmt, "ap", 2) == 0)
-					fprintf (outfile, AMPM);
+					fprintf (outfile, "%s", AMPM);
 				if (strncmp (fmt, "hr", 2) == 0)
-					fprintf (outfile, HLINE);
+					fprintf (outfile, "%s", HLINE);
 				if (strncmp (fmt, "tg", 2) == 0) {
 					tagnumber = SelectRandom (0, taglines);
 					GetTagLine (tagfile, tagline, tagnumber, shortDate, datefile, special);
@@ -538,8 +539,8 @@ int MakeTagCustom (char custom1[], char custom2[], char filename[], char tagfile
 					optarray[special] = 0;
 				}
 				if (strncmp (fmt, "vi", 2) == 0)
-					fprintf (outfile, VersionInfo);
-				strcpy (fmt, "   ");
+					fprintf (outfile, "%s", VersionInfo);
+				strcpy (fmt, "  ");
 				c = '\0';
 			}
 		} else {
@@ -585,50 +586,74 @@ void TaRTSetup (char custom1[], char custom2[], char customfile[], char sigfile[
 		strcpy (tagfile, "<Choices$Write>.TaRT.taglines");
 		strcpy (datefile, "Choices:TaRT.SpecialDates");
 #else
-		strcpy (customfile, "~/.custom");
+		strcpy (customfile, "~/.tart-custom");
 		strcpy (sigfile, "~/.signature");
-		strcpy (tagfile, "/etc/tag.trt");
-		strcpy (datefile, "~/.specialdates");
+		strcpy (tagfile, "/etc/tart.tags");
+		strcpy (datefile, "~/.tartdates");
 #endif
 	}
 	StripCR (custom1);
 	memset(ptmp, '-', TAGLEN - 48);
 	ptmp[TAGLEN - 48] = '\0';
 	printf (YELLOW "\nEnter text for first custom line (%2d chars max): %s|" GREEN "\n[%s]\n" NORMAL "> ", TAGLEN, ptmp, custom1);
-	fgets (tmp, TAGLEN +1, stdin);
+	if (fgets (tmp, TAGLEN +1, stdin) != NULL)
         if (strlen(tmp) == TAGLEN) strcat(tmp,"\n");
 
 	if (tmp[0] != '\n')
 		strcpy (custom1, tmp);
 
-	fgets(tmp, 255, stdin); /* flush the input buffer */
+	if (fgets(tmp, 255, stdin) == NULL)
+	{
+		printf("error reading from stdin\n"); /* flush the input buffer */
+		exit(1);
+	}
 	StripCR (custom2);
 	memset(ptmp, '-', TAGLEN - 49);
 	ptmp[TAGLEN - 49] = '\0';
 	printf (YELLOW "\nEnter text for second custom line (%2d chars max): %s|" GREEN "\n[%s]\n" NORMAL "> ", TAGLEN, ptmp, custom2);
-	fgets (tmp, TAGLEN +1, stdin);
+	if (fgets (tmp, TAGLEN +1, stdin) != NULL)
         if (strlen(tmp) == TAGLEN) strcat(tmp,"\n");
 	if (tmp[0] != '\n')
 		strcpy (custom2, tmp);
 
-	fgets(tmp, 255, stdin); /* flush the input buffer */
+	if (fgets(tmp, 255, stdin) == NULL) /* flush the input buffer */
+	{
+		printf("error reading from stdin\n"); /* flush the input buffer */
+		exit(1);
+	}
 	printf (YELLOW "\nEnter the full path to your signature file:" GREEN "\n[%s]\n" NORMAL "> ", sigfile);
-	fgets (tmp, 255, stdin);
+	if (fgets (tmp, 255, stdin) == NULL)
+	{
+		printf("error reading from stdin\n"); /* flush the input buffer */
+		exit(1);
+	}
 	if (tmp[0] != '\n')
 		strcpy (sigfile, tmp);
 
 	printf (YELLOW "\nEnter the full path to your custom layout file:" GREEN "\n[%s]\n" NORMAL "> ", customfile);
-	fgets (tmp, 255, stdin);
+	if (fgets (tmp, 255, stdin) == NULL)
+	{
+		printf("error reading from stdin\n"); /* flush the input buffer */
+		exit(1);
+	}
 	if (tmp[0] != '\n')
 		strcpy (customfile, tmp);
 
 	printf (YELLOW "\nEnter the full path to your special dates file:" GREEN "\n[%s]\n" NORMAL "> ", datefile);
-	fgets (tmp, 255, stdin);
+	if (fgets (tmp, 255, stdin) == NULL)
+	{
+		printf("error reading from stdin\n"); /* flush the input buffer */
+		exit(1);
+	}
 	if (tmp[0] != '\n')
 		strcpy (datefile, tmp);
 
 	printf (YELLOW "\nEnter the full path to the tagline database:" GREEN "\n[%s]\n" NORMAL "> ", tagfile);
-	fgets (tmp, 255, stdin);
+	if (fgets (tmp, 255, stdin) == NULL)
+	{
+		printf("error reading from stdin\n"); /* flush the input buffer */
+		exit(1);
+	}
 	if (tmp[0] != '\n')
 		strcpy (tagfile, tmp);
 
